@@ -8,12 +8,12 @@ use Data::Dumper;
 use Term::ANSIColor qw(:constants);
 require Exporter;
 
-$Proch::Seqfu::VERSION = '1.5.6';
+$Proch::Seqfu::VERSION     = '1.6.1';
 $Proch::Seqfu::fu_linesize = 0;
 $Proch::Seqfu::fu_verbose  = 0;
 
-our @ISA = qw(Exporter);
-our @EXPORT = qw(rc fu_printfasta fu_printfastq verbose has_seqfu seqfu_version);
+our @ISA       = qw(Exporter);
+our @EXPORT    = qw(rc fu_printfasta fu_printfastq verbose has_seqfu seqfu_version);
 our @EXPORT_OK = qw($fu_linesize $fu_verbose);  # symbols to export on request
 
 
@@ -51,7 +51,11 @@ sub verbose {
 sub rc {
     my   $sequence = reverse($_[0]);
     if (is_seq($sequence)) {
-        $sequence =~tr/ACGTacgt/TGCAtgca/;
+        if ($sequence =~ /U/i) {
+            $sequence =~ tr/ACGURYSWKMBDHVacguryswkmbdhv/UGCAYRSWMKVHDBugcayrswmkvhdb/;
+        } else {                      
+            $sequence =~ tr/ACGTRYSWKMBDHVacgtryswkmbdhv/TGCAYRSWMKVHDBtgcayrswmkvhdb/;
+        }
         return $sequence;
     }
 }
@@ -59,7 +63,7 @@ sub rc {
 
 sub is_seq {
     my $string = $_[0];
-    if ($string =~/[^ACGTRYSWKMBDHVN]/i) {
+    if ($string =~/[^ACGTRYSWKMBDHVNU]/i) {
         return 0;
     } else {
         return 1;
@@ -81,19 +85,24 @@ sub split_string {
 
 
 sub seqfu_version {
-	my $cmd = `seqfu version`;
+    my $cmd = '';
+    eval {
+        $cmd =  `seqfu version 2>/dev/null` // '';
+    };
     chomp($cmd);
-    if ($cmd =~/^(\d).(\d).(\d)$/) {
+    if (length($@) > 0) {
+        return -2;
+    } elsif ($cmd =~/^(\d+)\.(\d+)\.?(\d+)?$/) {
         return $cmd;
     } else {
-        return -1;
+        return "-" . $cmd;
     }
 }
 
 
 sub has_seqfu {
     my $ver = seqfu_version();
-    if ($ver == -1) {
+    if (substr($ver, 0, 1) eq '-') {
         return 0
     } elsif (length($ver) > 0) {
         return 1
@@ -113,7 +122,7 @@ Proch::Seqfu - Helper module to support Seqfu tools
 
 =head1 VERSION
 
-version 1.5.6
+version 1.5.7
 
 =head1 Proch::Seqfu
 
